#!/usr/bin/env python3
#--------------------------------------------------------------#
# Script to extract water depths at observation points
#--------------------------------------------------------------#
import sys
import os
import xarray as xr
import numpy as np
import pandas as pd
import scipy.interpolate
from scipy import integrate
import matplotlib.pyplot as plt
import matplotlib.cm as cm
xr.set_options(display_max_rows=1000)
np.set_printoptions(threshold=sys.maxsize)
#--------------------------------------------------------------#
## User input settings
layer2Plot = 0		# Specify 0 for half of the layers used in the simulation (mid height)
#--------------------------------------------------------------#
## Read from command line
nArgv = len(sys.argv)
if nArgv <= 1:
    print('Missing folder(s) argument. Specify one or more folders to run this script!')
    sys.exit()
else:
  fig, axi = plt.subplots((len(sys.argv)-1),1)  
  for iF,ax in zip(range(1,nArgv),axi):
    # Get map file data:
    fileType = 0
    file=sys.argv[iF]+'/DFM_OUTPUT_FlowFM/FlowFM_map.nc'
    if (not os.path.isfile(file)):
      fileType = 1
      file=sys.argv[iF]+'/DFM_OUTPUT_FlowFM_short/data.nc'

    ds = xr.open_dataset(file)

    # Get the numbers of sigma layers
    nLayers = ds.mesh2d_nLayers
    if (layer2Plot == 0):
      layer2Plot = nLayers[-1]//2

    # Get velocities and water levels
    if (fileType == 0):
      velX = np.array(ds.mesh2d_ucx)[-1]
      velY = np.array(ds.mesh2d_ucy)[-1]
      velZ = np.array(ds.mesh2d_ucz)[-1]
      waterLevel = np.array(ds.mesh2d_s1)[-1]
    else:
      velX = np.array(ds.mesh2d_ucx)
      velY = np.array(ds.mesh2d_ucy)
      velZ = np.array(ds.mesh2d_ucz)
      waterLevel = np.array(ds.mesh2d_s1)

    vel = np.sqrt(velX**2 + velY**2)
    xcoords = np.array(ds.mesh2d_face_x)
    ycoords = np.array(ds.mesh2d_face_y)
    bl = np.array(ds.mesh2d_flowelem_bl)
    waterDepth = waterLevel - bl

#    sc = ax.scatter(xcoords,ycoords,s=0.5,c=vel[:,layer2Plot],cmap=cm.jet, vmax=2.5)
    sc = ax.scatter(xcoords,ycoords,s=0.5,c=np.mean(vel,axis=1),cmap=cm.jet, vmax=3.0)
#    sc = ax.scatter(xcoords,ycoords,s=0.5,c=waterDepth,cmap=cm.jet, vmin=0.8, vmax=2.2)
    fig.colorbar(sc)
    ax.set_title('Case 1 ' + str(sys.argv[iF][0:-3].split('/')[1]) + ' - Hub Height Velocities (m/s)',fontsize=10)
#    ax.set_title('Case 1 ' + str(sys.argv[iF][0:-3].split('/')[1]) + ' - Water Depth (m)',fontsize=10)
    ax.set_ylabel('Width (m)')

  axi[-1].set_xlabel('Distance (m)')
  plt.tight_layout()
  plt.show()

